@@ -24,7 +24,7 @@ if (Sys.getenv("POSTGRES_USER") != "" & Sys.getenv("POSTGRES_HOST") != "" & Sys.
                      user=Sys.getenv("POSTGRES_USER"),
                      password=Sys.getenv("POSTGRES_PASSWD"),
                      host=Sys.getenv("POSTGRES_HOST"),
-                     dbname=Sys.getenv("POSTGRES_DATABSE"))
+                     dbname=Sys.getenv("POSTGRES_DATABASE"))
 
     ## run a simple query and show the query result
     res <- dbGetQuery(con, paste("select datname,encoding,datallowconn from pg_database",
